@@ -10,8 +10,22 @@ def _is_git_repo():
     return os.path.isdir('./.git')
 
 
+def _has_barb_dir():
+    return os.path.isdir('./.barb')
+
+
+def _has_barbrc():
+    return os.path.exists('./.barbrc.toml')
+
+
 def _initialize():
-    os.mkdir('.barb')
+    if not _has_barb_dir():
+        os.mkdir('.barb')
+
+    if not _has_barbrc():
+        with open('./.barbrc.toml') as f:
+            f.write('\n')
+
     install_base_hooks()
 
 
